@@ -18,9 +18,9 @@ from pwbus.engines.engine_monitor import EngineMonitor
 
 class EngineManager():
 
-    def __init__(self):
+    def __init__(self, registry_file):
         # Load registry entries
-        self.registry_loader = RegistryLoader()
+        self.registry_loader = RegistryLoader(registry_file)
         self.registry_loader.load()
 
     # EngineManager.action
