@@ -16,12 +16,14 @@ from pwbus.connectors.redis import RedisConnector
 
 
 class RegistryLoader(RedisConnector):
+    def __init__(self, registry_file):
+        self.registry_file = registry_file
 
     # RegistryLoader.load
     #
     def load(self):
         try:
-            with open(getenv['PWBUS_REGISTRY']) as json_file:
+            with open(self.registry_file) as json_file:
                 registry_list = load(json_file)
 
             with self.getConnectionPool().item() as connection:
@@ -43,7 +45,7 @@ class RegistryLoader(RedisConnector):
         engines = []
 
         try:
-            with open(getenv['PWBUS_REGISTRY']) as json_file:
+            with open(self.registry_file) as json_file:
                 registry_list = load(json_file)
 
             for channel_entry in registry_list:
@@ -66,7 +68,7 @@ class RegistryLoader(RedisConnector):
         channels = []
 
         try:
-            with open(getenv['PWBUS_REGISTRY']) as json_file:
+            with open(self.registry_file) as json_file:
                 registry_list = load(json_file)
 
             for channel_entry in registry_list:
